#!/bin/sh
# script for execution of deployed applications
#
# Sets up the MCR environment for the current $ARCH and executes 
# the specified command.
#
exe_name=$0
exe_dir=`dirname "$0"`
if [ $# -lt "3" ]; then
echo "----------------------------------------------------------------------------------------------"
echo "                     3D Rician Mixture Model
 
Example usage: 
./run_ricemixmodel3D_v3_Release_v1.sh inputfilename outputdirectory modality MCRROOT(optional)

The inputfile is either a XML file or a NIFTI file. If it is a XML,
then the raw file must be in the same directory of the xml. The 
input 3D volume must be skull-stripped.

The outputdirectory is where 4 files are going to be written, namely 
csf, gm, wm memberships (FLOAT) and the hard segmentation (UNSIGHNED INT).

Modality is either SPGR (enter spgr) or MPRAGE(enter mprage)

This is a parallelized code, it uses 3 CPUs.

Default MCRROOT is /usr/matlab_2012a. Change the root if necessary.
This executable is compatible with 2012a version, anything less may not work."
echo "----------------------------------------------------------------------------------------------"
exit 1
else
INPUT=$1
OUTDIR=$2
MODAL=$3
TEMP=$4

  echo Setting up environment variables
  if [ "x$TEMP" = "x" ]; then
    echo "MCR ROOT is not mentioned, using default."
    export MCRROOT=/usr/matlab_R2012a
  else
    MCRROOT=$TEMP
  fi
  LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
	MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre/lib/amd64 ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
  XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
  export LD_LIBRARY_PATH;
  export XAPPLRESDIR;
#  echo LD_LIBRARY_PATH is ${LD_LIBRARY_PATH};
  shift 1
  args=
  while [ $# -gt 0 ]; do
      token=`echo "$1" | sed 's/ /\\\\ /g'`   # Add blackslash before each blank
      args="${args} ${token}" 
      shift
  done
  echo Input Image: $INPUT
  echo Outpur Directory: $OUTDIR
  echo Modality = $MODAL
  "${exe_dir}"/ricemixmodel3D_v3_Release $INPUT $OUTDIR $MODAL

exit
fi

